@@ -96,16 +96,20 @@ def main():
         create_csv_from_currently_uploaded_files(args.csv_dataset_name, args.file_name, settings) 
 
     if args.action == 'upload-csv':
-        upload_csv(args)
+        upload_csv(args.file_name, args.project_id, args.tag)
 
+    result = None
     if args.action == 'run-job':
-        jobs.run_job(args)
+        result = jobs.run_job(args.project_id, args.tag)
     if args.action == 'list-jobs':
-        jobs.list_jobs(args)
+        result = jobs.list_jobs(args.project_id)
     if args.action == 'export-job':
-        jobs.export_job(args)
+        result = jobs.export_job(args.job_id, args.raw, args.worker_data)
     if args.action == 'list-projects':
-        projects.list_projects(args)
+        result = projects.list_projects()
+
+    if result:
+        print(result)
 
 
 if __name__ == "__main__":
